@@ -6,6 +6,9 @@ from domainpy.utils.dictable import Dictable
 
 class ApplicationCommand(Constructable, Immutable, Dictable):
 
+    class Struct(Constructable, Immutable, Dictable):
+        pass
+
     def __init__(self, *args, **kwargs):
         self.__dict__.update({
             '__trace_id__': kwargs.pop('__trace_id__', str(uuid4())),
