@@ -5,4 +5,7 @@ from .mappers.eventmapper import EventMapper, EventRecord
 
 from .bus import Bus, Commutator
 from .registry import Registry
-from .subscriber import Subscriber
\ No newline at end of file
+from .subscriber import Subscriber
+
+from .constructable import Constructable
+from .dictable import Dictable
\ No newline at end of file
